@@ -47,8 +47,10 @@ function _aws_cdk_aws_ivs_CfnChannelProps(p) {
         return;
     visitedObjects.add(p);
     try {
-        if (!visitedObjects.has(p.tags))
-            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
     }
     finally {
         visitedObjects.delete(p);
@@ -61,8 +63,10 @@ function _aws_cdk_aws_ivs_CfnPlaybackKeyPairProps(p) {
         return;
     visitedObjects.add(p);
     try {
-        if (!visitedObjects.has(p.tags))
-            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
     }
     finally {
         visitedObjects.delete(p);
@@ -75,8 +79,10 @@ function _aws_cdk_aws_ivs_CfnRecordingConfigurationProps(p) {
         return;
     visitedObjects.add(p);
     try {
-        if (!visitedObjects.has(p.tags))
-            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
     }
     finally {
         visitedObjects.delete(p);
@@ -95,8 +101,10 @@ function _aws_cdk_aws_ivs_CfnStreamKeyProps(p) {
         return;
     visitedObjects.add(p);
     try {
-        if (!visitedObjects.has(p.tags))
-            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
     }
     finally {
         visitedObjects.delete(p);
